This project contains some utilities that I personally wrote, and end up
using pretty often.  It let's me easily include them in different projects,
while keeping them synchronized with minimum effort.
